
# THIS FILE IS GENERATED FROM PYART SETUP.PY
short_version = '1.11.2'
version = '1.11.2'
full_version = '1.11.2'
git_revision = '8bbe05f3eaf1d47d1132d36548680c005f7c07c5'
release = True

if not release:
    version = full_version
